@@ -111,7 +111,8 @@ terminal_info_bar_format_text (TerminalInfoBar *bar,
 
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
   gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.0);
 
   gtk_box_pack_start (GTK_BOX (priv->content_box), label, FALSE, FALSE, 0);
   gtk_widget_show_all (priv->content_box);
