@@ -119,12 +119,12 @@ remove_reorder_bindings (GtkBindingSet    *binding_set,
 
 static void
 terminal_notebook_add_screen (TerminalMdiContainer *container,
-                              TerminalScreen *screen)
+                              TerminalScreen *screen,
+                              int position)
 {
   TerminalNotebook *notebook = TERMINAL_NOTEBOOK (container);
   GtkNotebook *gtk_notebook = GTK_NOTEBOOK (notebook);
   GtkWidget *screen_container, *tab_label;
-  const int position = -1;
 
   g_warn_if_fail (gtk_widget_get_parent (GTK_WIDGET (screen)) == NULL);
 
