@@ -192,15 +192,15 @@ terminal_tab_label_constructed (GObject *object)
   priv->label = label = gtk_label_new (NULL);
   gtk_widget_set_halign (label, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (label, GTK_ALIGN_BASELINE);
-  gtk_misc_set_padding (GTK_MISC (label), 0, 0);
+  gtk_widget_set_margin_start  (label, 0);
+  gtk_widget_set_margin_end    (label, 0);
+  gtk_widget_set_margin_top    (label, 0);
+  gtk_widget_set_margin_bottom (label, 0);
+
   gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
   gtk_label_set_single_line_mode (GTK_LABEL (label), TRUE);
 
-#if GTK_CHECK_VERSION (3, 12, 0)
   gtk_box_set_center_widget (GTK_BOX (hbox), label);
-#else
-  gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-#endif
 
   priv->close_button = close_button = terminal_close_button_new ();
   gtk_widget_set_tooltip_text (close_button, _("Close tab"));
